// Copyright 2019 Varjo Technologies Oy. All rights reserved.

#ifndef VARJO_TYPES_H
#define VARJO_TYPES_H

#include <cstdint>

#if defined __cplusplus
extern "C" {
#endif

/**
 * Type representing logical values - True and False.
 */
typedef int32_t varjo_Bool;
static const varjo_Bool varjo_False = 0;  //!< Value representing False
static const varjo_Bool varjo_True = 1;   //!< Value representing True

/**
 * Time in nanoseconds. Absolute times are relative to an epoch which is constant during execution of the program.
 */
typedef int64_t varjo_Nanoseconds;

/**
 * 64bit floating point 3D vector.
 */
typedef struct varjo_Vector3D {
    double x;  //!< X coordinate.
    double y;  //!< Y coordinate.
    double z;  //!< Z coordinate.
} varjo_Vector3D;

/**
 * Double precision 3x3 matrix.
 * The matrix usage convention is that values are stored in column-major order.
 */
typedef struct varjo_Matrix3x3 {
    double value[9];
} varjo_Matrix3x3;

#if defined __cplusplus
}
#endif

#endif  // VARJO_TYPES_H
